# Camembert

This library is for configuring and setting middlewares and hooks for Falcon framework.

## Requirements

Please refer to `requirements.txt` for list of requirements.

## List of middlewares

- [x] Converting request to JSON middleware 
- [x] Requests Logging middleware
- [x] Response headers middleware
- [x] Content Type middleware
- [x] HTTPS required

## Installing

Run dependencies using `python3 -m pip install -r requirements.txt --cert <proxy-cert>` in your terminal.

Then run `python3 setup.py install`

Or you can install package using `pip install camembert`

Go to [Pypi page](https://pypi.org/project/camembert/) for more details.

## Examples

Please see `EXAMPLES.md` for examples.

